==> hinemos_src-4.0.3.tar.gz: HinemosManager/src_logfile/com/clustercontrol/logfile/factory/AddMonitorLogfileString.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.logfile.factory;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import com.clustercontrol.commons.scheduler.TriggerScheduler;
import com.clustercontrol.logfile.util.ControlLogfileInfo;
import com.clustercontrol.logfile.util.SendTopic;
import com.clustercontrol.monitor.run.factory.AddMonitorStringValueType;

/**
 * ログファイル監視情報マネージャに登録するクラス<BR>
 *
 * @version 4.0.0
 * @since 4.0.0
 */
public class AddMonitorLogfileString extends AddMonitorStringValueType{

	/* (non-Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	protected boolean addCheckInfo() throws CreateException, NamingException{

		// ログファイル監視情報を追加
		ControlLogfileInfo logfile = new ControlLogfileInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());

		// Topic送信
		SendTopic sendTopic = new SendTopic();
		/*
		 * TODO
		 * 性能向上のため、facilityIdにはlocal.getExecNodeList(monitorInfo.getFacilityId)を入れると良い。
		 * monitorInfoは追加されたものを利用する。
		 * facilityId=nullでは、全エージェントからアクセスが来てしまう。
		 */
		String facilityId = null;
		sendTopic.put(facilityId);

		return logfile.add(m_monitorInfo.getLogfileCheckInfo());
	}

	/**
	 * スケジュール実行の遅延時間を返します。
	 */
	@Override
	protected int getDelayTime() {
		return 0;
	}

	/**
	 * スケジュール実行種別を返します。
	 */
	@Override
	protected String getTriggerType() {
		return TriggerScheduler.TRIGGER_TYPE_NONE;
	}
}

==> hinemos_src-5.0.1.tar.gz: HinemosManager/src_logfile/com/clustercontrol/logfile/factory/AddMonitorLogfileString.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.logfile.factory;

import com.clustercontrol.fault.InvalidRole;
import com.clustercontrol.fault.MonitorNotFound;
import com.clustercontrol.logfile.util.ControlLogfileInfo;
import com.clustercontrol.monitor.run.factory.AddMonitorStringValueType;
import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;

/**
 * ログファイル監視情報マネージャに登録するクラス<BR>
 *
 * @version 4.0.0
 * @since 4.0.0
 */
public class AddMonitorLogfileString extends AddMonitorStringValueType{

	/* (non-Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	protected boolean addCheckInfo() throws MonitorNotFound, InvalidRole {

		// ログファイル監視情報を追加
		ControlLogfileInfo logfile = new ControlLogfileInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());

		return logfile.add(m_monitorInfo.getLogfileCheckInfo());
	}

	/**
	 * スケジュール実行の遅延時間を返します。
	 */
	@Override
	protected int getDelayTime() {
		return 0;
	}

	/**
	 * スケジュール実行種別を返します。
	 */
	@Override
	protected TriggerType getTriggerType() {
		return TriggerType.NONE;
	}
}
